@@ -50,27 +50,34 @@ can set the BOTOCORE_TEST_ID env var with the ``suite_id:test_id`` syntax.
     BOTOCORE_TEST_ID=5:1 pytest test/unit/test_protocols.py
 
 """
-import os
 import copy
+import os
+from base64 import b64decode
+from calendar import timegm
 from enum import Enum
 
-from base64 import b64decode
+import pytest
 from dateutil.tz import tzutc
 
-import pytest
-
-from botocore.awsrequest import HeadersDict
-from botocore.compat import json, OrderedDict, urlsplit
+from botocore.awsrequest import HeadersDict, prepare_request_dict
+from botocore.compat import OrderedDict, json, urlsplit
 from botocore.eventstream import EventStream
-from botocore.model import ServiceModel, OperationModel
-from botocore.serialize import EC2Serializer, QuerySerializer, \
-        JSONSerializer, RestJSONSerializer, RestXMLSerializer
-from botocore.parsers import QueryParser, JSONParser, \
-        RestJSONParser, RestXMLParser, EC2QueryParser
+from botocore.model import NoShapeFoundError, OperationModel, ServiceModel
+from botocore.parsers import (
+    EC2QueryParser,
+    JSONParser,
+    QueryParser,
+    RestJSONParser,
+    RestXMLParser,
+)
+from botocore.serialize import (
+    EC2Serializer,
+    JSONSerializer,
+    QuerySerializer,
+    RestJSONSerializer,
+    RestXMLSerializer,
+)
 from botocore.utils import parse_timestamp, percent_encode_sequence
-from botocore.awsrequest import prepare_request_dict
-from calendar import timegm
-from botocore.model import NoShapeFoundError
 
 TEST_DIR = os.path.join(
     os.path.dirname(os.path.abspath(__file__)),
@@ -168,6 +175,7 @@ class MockRawResponse(object):
     def stream(self):
         yield self._data
 
+
 @pytest.mark.parametrize(
     "json_description, case, basename",
     _compliance_tests(TestType.OUTPUT)
@@ -374,14 +382,25 @@ def _serialize_request_description(request_dict):
 def _assert_requests_equal(actual, expected):
     assert_equal(actual['body'], expected.get('body', '').encode('utf-8'),
                  'Body value')
-    actual_headers = dict(actual['headers'])
-    expected_headers = expected.get('headers', {})
-    assert_equal(actual_headers, expected_headers, "Header values")
+    actual_headers = HeadersDict(actual['headers'])
+    expected_headers = HeadersDict(expected.get('headers', {}))
+    excluded_headers = expected.get('forbidHeaders', [])
+    _assert_expected_headers_in_request(
+        actual_headers, expected_headers, excluded_headers
+    )
     assert_equal(actual['url_path'], expected.get('uri', ''), "URI")
     if 'method' in expected:
         assert_equal(actual['method'], expected['method'], "Method")
 
 
+def _assert_expected_headers_in_request(actual, expected, excluded_headers):
+    for header, value in expected.items():
+        assert header in actual
+        assert actual[header] == value
+    for header in excluded_headers:
+        assert header not in actual
+
+
 def _walk_files():
     # Check for a shortcut when running the tests interactively.
     # If a BOTOCORE_TEST env var is defined, that file is used as the
